==> c8y_client-0.0.1.tar.gz: lib/src/user/implementation/user.dart <==

import 'package:c8y_client/src/sdk/client/rest_connector.dart';
import 'package:c8y_client/src/user/model/current_user_representation.dart';
import 'package:c8y_client/src/user/model/user_api.dart';
import 'package:c8y_client/src/user/model/user_representation.dart';
import 'package:http_parser/http_parser.dart';

class User implements UserApi {
  final RestConnector _restConnector;
  String _url;
  final String _path = '/user/';

  User(this._restConnector, String host) {
    _url = host + _path;
  }

  @override
  Future<UserRepresentation> create(String var1, UserRepresentation var2) {
    // TODO: implement create
    return null;
  }

  @override
  void delete(String var1, String var2) {
    // TODO: implement delete
  }

  @override
  Future<CurrentUserRepresentation> currentUser() async{
    return (await _restConnector.get(
        _url + 'currentUser', MediaType('', ''), CurrentUserRepresentation.fromJson)) as CurrentUserRepresentation;
  }

  @override
  Future<UserRepresentation> currentUserWithCustomProperties() {
    // TODO: implement getCurrentUserWithCustomProperties
    return null;
  }

  @override
  Future<UserRepresentation> user(String var1, String var2) {
    // TODO: implement getUser
    return null;
  }

  @override
  Future<UserRepresentation> update(String var1, UserRepresentation var2) {
    // TODO: implement update
    return null;
  }

  @override
  Future<CurrentUserRepresentation> updateCurrentUser(
      CurrentUserRepresentation var1) {
    // TODO: implement updateCurrentUser
    return null;
  }
}

==> c8y_client-0.0.3.tar.gz: lib/src/user/implementation/user.dart <==

import 'package:c8y_client/src/sdk/client/rest_connector.dart';
import 'package:c8y_client/src/user/model/current_user_representation.dart';
import 'package:c8y_client/src/user/model/user_api.dart';
import 'package:c8y_client/src/user/model/user_representation.dart';
import 'package:http_parser/http_parser.dart';

class User implements UserApi {
  final RestConnector _restConnector;
  String _url;
  final String _path = '/user/';

  User(this._restConnector, String host) {
    _url = host + _path;
  }

  @override
  Future<UserRepresentation> create(String var1, UserRepresentation var2) {
    // TODO: implement create
    return null;
  }

  @override
  void delete(String var1, String var2) {
    // TODO: implement delete
  }

  @override
  Future<CurrentUserRepresentation> currentUser() async{
    return (await _restConnector.get(
        _url + 'currentUser', MediaType('', ''), CurrentUserRepresentation.fromJson));
  }

  @override
  Future<UserRepresentation> currentUserWithCustomProperties() {
    // TODO: implement getCurrentUserWithCustomProperties
    return null;
  }

  @override
  Future<UserRepresentation> user(String var1, String var2) {
    // TODO: implement getUser
    return null;
  }

  @override
  Future<UserRepresentation> update(String var1, UserRepresentation var2) {
    // TODO: implement update
    return null;
  }

  @override
  Future<CurrentUserRepresentation> updateCurrentUser(
      CurrentUserRepresentation var1) {
    // TODO: implement updateCurrentUser
    return null;
  }
}
